==> huaweicloudsdkcloudrtc-3.0.68-py2.py3-none-any.whl: huaweicloudsdkcloudrtc/v2/model/mix_user_background_image.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class MixUserBackgroundImage:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'user_id': 'str',
        'image_uri': 'str'
    }

    attribute_map = {
        'user_id': 'user_id',
        'image_uri': 'image_uri'
    }

    def __init__(self, user_id=None, image_uri=None):
        """MixUserBackgroundImage - a model defined in huaweicloud sdk"""
        
        

        self._user_id = None
        self._image_uri = None
        self.discriminator = None

        self.user_id = user_id
        self.image_uri = image_uri

    @property
    def user_id(self):
        """Gets the user_id of this MixUserBackgroundImage.

        需要设置背景图的用户ID

        :return: The user_id of this MixUserBackgroundImage.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this MixUserBackgroundImage.

        需要设置背景图的用户ID

        :param user_id: The user_id of this MixUserBackgroundImage.
        :type: str
        """
        self._user_id = user_id

    @property
    def image_uri(self):
        """Gets the image_uri of this MixUserBackgroundImage.

        需要设置背景图的地址，图片先上传obs，格式s3://bucket/object

        :return: The image_uri of this MixUserBackgroundImage.
        :rtype: str
        """
        return self._image_uri

    @image_uri.setter
    def image_uri(self, image_uri):
        """Sets the image_uri of this MixUserBackgroundImage.

        需要设置背景图的地址，图片先上传obs，格式s3://bucket/object

        :param image_uri: The image_uri of this MixUserBackgroundImage.
        :type: str
        """
        self._image_uri = image_uri

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MixUserBackgroundImage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcloudrtc-3.0.89-py2.py3-none-any.whl: huaweicloudsdkcloudrtc/v2/model/mix_user_background_image.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class MixUserBackgroundImage:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'user_id': 'str',
        'image_uri': 'str'
    }

    attribute_map = {
        'user_id': 'user_id',
        'image_uri': 'image_uri'
    }

    def __init__(self, user_id=None, image_uri=None):
        """MixUserBackgroundImage

        The model defined in huaweicloud sdk

        :param user_id: 需要设置背景图的用户ID
        :type user_id: str
        :param image_uri: 需要设置背景图的地址，图片先上传obs，格式s3://bucket/object
        :type image_uri: str
        """
        
        

        self._user_id = None
        self._image_uri = None
        self.discriminator = None

        self.user_id = user_id
        self.image_uri = image_uri

    @property
    def user_id(self):
        """Gets the user_id of this MixUserBackgroundImage.

        需要设置背景图的用户ID

        :return: The user_id of this MixUserBackgroundImage.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this MixUserBackgroundImage.

        需要设置背景图的用户ID

        :param user_id: The user_id of this MixUserBackgroundImage.
        :type user_id: str
        """
        self._user_id = user_id

    @property
    def image_uri(self):
        """Gets the image_uri of this MixUserBackgroundImage.

        需要设置背景图的地址，图片先上传obs，格式s3://bucket/object

        :return: The image_uri of this MixUserBackgroundImage.
        :rtype: str
        """
        return self._image_uri

    @image_uri.setter
    def image_uri(self, image_uri):
        """Sets the image_uri of this MixUserBackgroundImage.

        需要设置背景图的地址，图片先上传obs，格式s3://bucket/object

        :param image_uri: The image_uri of this MixUserBackgroundImage.
        :type image_uri: str
        """
        self._image_uri = image_uri

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MixUserBackgroundImage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
